<?php

namespace Blackwhite29\Fbuids\Http\Controllers;

use App\Http\Controllers\UserApiController as UserController;
use Blackwhite29\Fbuids\Http\Requests\FbuidsUserApiRequest;
use Blackwhite29\Fbuids\Interfaces\FbuidsRepositoryInterface;
use Blackwhite29\Fbuids\Models\Fbuids;

/**
 * User API controller class.
 */
class FbuidsUserApiController extends UserController
{
    /**
     * Initialize fbuids controller.
     *
     * @param type FbuidsRepositoryInterface $fbuids
     *
     * @return type
     */
    public function __construct(FbuidsRepositoryInterface $fbuids)
    {
        $this->repository = $fbuids;
        parent::__construct();
    }

    /**
     * Display a list of fbuids.
     *
     * @return json
     */
    public function index(FbuidsUserApiRequest $request)
    {
        $fbuids  = $this->repository
            ->pushCriteria(new \Lavalite\Fbuids\Repositories\Criteria\FbuidsUserCriteria())
            ->setPresenter('\\Blackwhite29\\Fbuids\\Repositories\\Presenter\\FbuidsListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $fbuids['code'] = 2000;
        return response()->json($fbuids) 
            ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display fbuids.
     *
     * @param Request $request
     * @param Model   Fbuids
     *
     * @return Json
     */
    public function show(FbuidsUserApiRequest $request, Fbuids $fbuids)
    {

        if ($fbuids->exists) {
            $fbuids         = $fbuids->presenter();
            $fbuids['code'] = 2001;
            return response()->json($fbuids)
                ->setStatusCode(200, 'SHOW_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }

    /**
     * Show the form for creating a new fbuids.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(FbuidsUserApiRequest $request, Fbuids $fbuids)
    {
        $fbuids         = $fbuids->presenter();
        $fbuids['code'] = 2002;
        return response()->json($fbuids)
            ->setStatusCode(200, 'CREATE_SUCCESS');
    }

    /**
     * Create new fbuids.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(FbuidsUserApiRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $fbuids          = $this->repository->create($attributes);
            $fbuids          = $fbuids->presenter();
            $fbuids['code']  = 2004;

            return response()->json($fbuids)
                ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message' => $e->getMessage(),
                'code'    => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }

    }

    /**
     * Show fbuids for editing.
     *
     * @param Request $request
     * @param Model   $fbuids
     *
     * @return json
     */
    public function edit(FbuidsUserApiRequest $request, Fbuids $fbuids)
    {
        if ($fbuids->exists) {
            $fbuids         = $fbuids->presenter();
            $fbuids['code'] = 2003;
            return response()-> json($fbuids)
                ->setStatusCode(200, 'EDIT_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }
    }

    /**
     * Update the fbuids.
     *
     * @param Request $request
     * @param Model   $fbuids
     *
     * @return json
     */
    public function update(FbuidsUserApiRequest $request, Fbuids $fbuids)
    {
        try {

            $attributes = $request->all();

            $fbuids->update($attributes);
            $fbuids         = $fbuids->presenter();
            $fbuids['code'] = 2005;

            return response()->json($fbuids)
                ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the fbuids.
     *
     * @param Request $request
     * @param Model   $fbuids
     *
     * @return json
     */
    public function destroy(FbuidsUserApiRequest $request, Fbuids $fbuids)
    {

        try {

            $t = $fbuids->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('fbuids::fbuids.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
