<?php

namespace Blackwhite29\Fbuids\Http\Controllers;

use App\Http\Controllers\UserWebController as UserController;
use Form;
use Blackwhite29\Fbuids\Http\Requests\FbuidsUserWebRequest;
use Blackwhite29\Fbuids\Interfaces\FbuidsRepositoryInterface;
use Blackwhite29\Fbuids\Models\Fbuids;

class FbuidsUserWebController extends UserController
{
    /**
     * Initialize fbuids controller.
     *
     * @param type FbuidsRepositoryInterface $fbuids
     *
     * @return type
     */
    public function __construct(FbuidsRepositoryInterface $fbuids)
    {
        $this->repository = $fbuids;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(FbuidsUserWebRequest $request)
    {
        $this->repository->pushCriteria(new \Lavalite\Fbuids\Repositories\Criteria\FbuidsUserCriteria());
        $fbuids = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('fbuids::fbuids.names').' :: ');

        return $this->theme->of('fbuids::user.fbuids.index', compact('fbuids'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Fbuids $fbuids
     *
     * @return Response
     */
    public function show(FbuidsUserWebRequest $request, Fbuids $fbuids)
    {
        Form::populate($fbuids);

        return $this->theme->of('fbuids::user.fbuids.show', compact('fbuids'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(FbuidsUserWebRequest $request)
    {

        $fbuids = $this->repository->newInstance([]);
        Form::populate($fbuids);

        return $this->theme->of('fbuids::user.fbuids.create', compact('fbuids'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(FbuidsUserWebRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $fbuids = $this->repository->create($attributes);

            return redirect(trans_url('/user/fbuids/fbuids'))
                -> with('message', trans('messages.success.created', ['Module' => trans('fbuids::fbuids.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Fbuids $fbuids
     *
     * @return Response
     */
    public function edit(FbuidsUserWebRequest $request, Fbuids $fbuids)
    {

        Form::populate($fbuids);

        return $this->theme->of('fbuids::user.fbuids.edit', compact('fbuids'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Fbuids $fbuids
     *
     * @return Response
     */
    public function update(FbuidsUserWebRequest $request, Fbuids $fbuids)
    {
        try {
            $this->repository->update($request->all(), $fbuids->getRouteKey());

            return redirect(trans_url('/user/fbuids/fbuids'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('fbuids::fbuids.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(FbuidsUserWebRequest $request, Fbuids $fbuids)
    {
        try {
            $this->repository->delete($fbuids->getRouteKey());
            return redirect(trans_url('/user/fbuids/fbuids'))
                ->with('message', trans('messages.success.deleted', ['Module' => trans('fbuids::fbuids.name')]))
                ->with('code', 204);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
