<?php

namespace Blackwhite29\Fbuids\Http\Requests;

use App\Http\Requests\Request as FormRequest;
use Illuminate\Http\Request;

class FbuidsUserApiRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize(Request $request)
    {
        $fbuids = $this->route('fbuids');
        if (is_null($fbuids)) {
            // Determine if the user is authorized to access fbuids module,
            return $request->user('api')->canDo('fbuids.fbuids.view');
        }

        if ($request->isMethod('POST') || $request->is('*/create')) {
            // Determine if the user is authorized to create an entry,
            return $request->user('api')->can('create', $fbuids);
        }

        if ($request->isMethod('PUT') || $request->isMethod('PATCH') || $request->is('*/edit')) {
            // Determine if the user is authorized to update an entry,
            return $request->user('api')->can('update', $fbuids);
        }

        if ($request->isMethod('DELETE')) {
            // Determine if the user is authorized to delete an entry,
            return $request->user('api')->can('delete', $fbuids);
        }

        // Determine if the user is authorized to view the module.
        return $request->user('api')->can('view', $fbuids);

    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules(Request $request)
    {
        if ($request->isMethod('POST')) {
            // validation rule for create request.
            return [
                'fbuid'               => 'required',
                'category_id'         => 'required',
            ];
        }
        
        if ($request->isMethod('PUT') || $request->isMethod('PATCH')) {
            // Validation rule for update request.
            return [
                'fbuid'               => 'required',
                'category_id'         => 'required',
            ];
        }

        // Default validation rule.
        return [

        ];
    }
}
