<?php

namespace Blackwhite29\Fbuids\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Blackwhite29\Fbuids\Models\Fbuids;

class FbuidsPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the fbuids.
     *
     * @param User $user
     * @param Fbuids $fbuids
     *
     * @return bool
     */
    public function view(User $user, Fbuids $fbuids)
    {
        if ($user->canDo('fbuids.fbuids.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $fbuids->user_id;
    }

    /**
     * Determine if the given user can create a fbuids.
     *
     * @param User $user
     * @param Fbuids $fbuids
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('fbuids.fbuids.create');
    }

    /**
     * Determine if the given user can update the given fbuids.
     *
     * @param User $user
     * @param Fbuids $fbuids
     *
     * @return bool
     */
    public function update(User $user, Fbuids $fbuids)
    {
        if ($user->canDo('fbuids.fbuids.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $fbuids->user_id;
    }

    /**
     * Determine if the given user can delete the given fbuids.
     *
     * @param User $user
     * @param Fbuids $fbuids
     *
     * @return bool
     */
    public function destroy(User $user, Fbuids $fbuids)
    {
        if ($user->canDo('fbuids.fbuids.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $fbuids->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
